@@ -6,7 +6,8 @@ import mimetypes
 from zipfile import ZipFile
 from io import BytesIO
 import logging
-from .env_utils import is_stg_or_prd_env
+from .env_utils import is_stg_or_prd_env, prod_bucket_env
+from .misc_utils import PRINT
 
 
 ###########################
@@ -24,7 +25,7 @@ class s3Utils(object):
         if we pass in env set the outfile and sys bucket from the environment
         '''
         # avoid circular ref
-        from dcicutils.beanstalk_utils import get_beanstalk_real_url
+        from .beanstalk_utils import get_beanstalk_real_url
         self.url = ''
         self.s3 = boto3.client('s3', region_name='us-east-1')
         if sys_bucket is None:
@@ -32,7 +33,7 @@ class s3Utils(object):
             if env:
                 if is_stg_or_prd_env(env):
                     self.url = get_beanstalk_real_url(env)
-                    env = 'fourfront-webprod'
+                    env = prod_bucket_env(env)
             # we use standardized naming schema, so s3 buckets always have same prefix
             sys_bucket = "elasticbeanstalk-%s-system" % env
             outfile_bucket = "elasticbeanstalk-%s-wfoutput" % env
@@ -93,8 +94,8 @@ class s3Utils(object):
             file_metadata = self.s3.head_object(Bucket=bucket, Key=key)
         except Exception as e:
             if print_error:
-                print("object %s not found on bucket %s" % (str(key), str(bucket)))
-                print(str(e))
+                PRINT("object %s not found on bucket %s" % (str(key), str(bucket)))
+                PRINT(str(e))
             return False
         return file_metadata
 
